@@ -1,7 +1,7 @@
 package Data::Clean::Base;
 
-our $DATE = '2015-03-26'; # DATE
-our $VERSION = '0.24'; # VERSION
+our $DATE = '2015-05-23'; # DATE
+our $VERSION = '0.25'; # VERSION
 
 use 5.010;
 use strict;
@@ -213,6 +213,7 @@ sub _generate_cleanser_code {
     push @code, '}'."\n";
 
     my $code = join("", @code).";";
+
     if ($ENV{LOG_CLEANSER_CODE} && $log->is_trace) {
         require String::LineNumber;
         $log->tracef("Cleanser code:\n%s",
@@ -221,6 +222,7 @@ sub _generate_cleanser_code {
     }
     eval "\$self->{code} = $code";
     die "Can't generate code: $@" if $@;
+    $self->{src} = $code;
 }
 
 sub clean_in_place {
@@ -251,7 +253,7 @@ Data::Clean::Base - Base class for Data::Clean::*
 
 =head1 VERSION
 
-This document describes version 0.24 of Data::Clean::Base (from Perl distribution Data-Clean-JSON), released on 2015-03-26.
+This document describes version 0.25 of Data::Clean::Base (from Perl distribution Data-Clean-JSON), released on 2015-05-23.
 
 =for Pod::Coverage ^(command_.+)$
 
@@ -386,7 +388,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Clean
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Data-Clean-JSON>.
+Source repository is at L<https://github.com/sharyanto/perl-Data-Clean-JSON>.
 
 =head1 BUGS
 
